@@ -20,11 +20,20 @@ Rcpp.system.file <- function(...){
     tools::file_path_as_absolute( base::system.file( ..., package = "Rcpp" ) )
 }
 
+## quote path if non-standard characters are used
+Rcpp.quoteNonStandard <- function(path) {
+    ## On unix, check if path has only characters that do not need quoting
+    noquote <- .Platform$OS.type == "unix" && grepl("^[[:alnum:]/._~+@%-]*$", path)
+    ## If no quoting needed return unchanged else quote input
+    if (noquote) path else shQuote(path)
+}
+
 ## Use R's internal knowledge of path settings to find the lib/ directory
 ## plus optinally an arch-specific directory on system building multi-arch
 RcppLdPath <- function() {
     #.Deprecated(msg=paste("This function is now deprecated as it has not",
     #                      "been needed since 2013."))
+    message("'RcppLdPath' has not been needed since 2013 (!!) and may get removed in 2027. Please update your 'Makevars'.")
     ""
 }
 
@@ -39,6 +48,7 @@ RcppLdPath <- function() {
 RcppLdFlags <- function() {
     #.Deprecated(msg=paste("This function is now deprecated as it has not",
     #                      "been needed since 2013."))
+    message("'RcppLdFlags' has not been needed since 2013 (!!) and may get removed in 2027. Please update your 'Makevars'.")
     ""
 }
 
@@ -47,12 +57,11 @@ canUseCXX0X <- function() { TRUE }  # .Call( "canUseCXX0X", PACKAGE = "Rcpp" )
 
 ## Provide compiler flags -- i.e. -I/path/to/Rcpp.h
 RcppCxxFlags <- function(cxx0x=FALSE) {
-    # path <- RcppLdPath()
     path <- Rcpp.system.file( "include" )
     if (.Platform$OS.type=="windows") {
         path <- asBuildPath(path)				# #nocov
     }
-    paste("-I", path, if (cxx0x && canUseCXX0X()) " -std=c++0x" else "", sep="")
+    paste0('-I', Rcpp.quoteNonStandard(path))
 }
 
 ## Shorter names, and call cat() directly
@@ -60,11 +69,13 @@ RcppCxxFlags <- function(cxx0x=FALSE) {
 CxxFlags <- function(cxx0x=FALSE) {
     #.Deprecated(msg=paste("This function is now deprecated as R uses minimally",
     #                      "viable compilers om all platforme."))
+    message("'CxxFlags' has not been needed since 2013 (!!) and may get removed in 2027. Please update your 'Makevars'.")
     cat(RcppCxxFlags(cxx0x=cxx0x))				# #nocov
 }
 
 ## LdFlags defaults to static linking on the non-Linux platforms Windows and OS X
 LdFlags <- function() {
+    message("'LdFlags' has not been needed since 2013 (!!) and may get removed in 2027. Please update your 'Makevars'.")
     cat(RcppLdFlags())
 }
 
@@ -76,11 +87,13 @@ RcppCapabilities <- capabilities <- function() .Call( rcpp_capabilities )
 RcppCxx0xFlags <- function() {
     #.Deprecated(msg=paste("This function is now deprecated as R uses minimally",
     #                      "viable compilers om all platforme."))
+    message("'RcppCxx0xFlags' has not been needed since 2013 (!!) and may get removed in 2027. Please update your 'Makevars'.")
     script <- Rcpp.system.file( "discovery", "cxx0x.R" )	# #nocov start
     flag <- capture.output( source( script ) )
     flag
 }
 
 Cxx0xFlags <- function() {
-    cat( RcppCxx0xFlags() )									# #nocov end
+    message("'Cxx0xFlags' has not been needed since 2013 (!!) and may get removed in 2027. Please update your 'Makevars'.")
+    cat(RcppCxx0xFlags())									# #nocov end
 }
