@@ -2,7 +2,7 @@
 //
 // DataFrame.h: Rcpp R/C++ interface class library -- data frames
 //
-// Copyright (C) 2010 - 2015  Dirk Eddelbuettel and Romain Francois
+// Copyright (C) 2010 - 2025  Dirk Eddelbuettel and Romain Francois
 //
 // This file is part of Rcpp.
 //
@@ -60,27 +60,32 @@ namespace Rcpp{
             return *this ;
         }
 
-        // By definition, the number of rows in a data.frame is contained
-        // in its row.names attribute. If it has row names of the form 1:n,
-        // they will be stored as {NA_INTEGER, -<nrow>}. Unfortunately,
-        // getAttrib(df, R_RowNamesSymbol) will force an expansion of that
-        // compact form thereby allocating a huge vector when we just want
-        // the row.names. Hence this workaround.
         inline int nrow() const {
-            SEXP rn = R_NilValue ;
-            SEXP att = ATTRIB( Parent::get__() )  ;
-            while( att != R_NilValue ){
-                if( TAG(att) == R_RowNamesSymbol ) {
-                    rn = CAR(att) ;
-                    break ;
-                }
-                att = CDR(att) ;
-            }
-            if (Rf_isNull(rn))
-                return 0;
-            if (TYPEOF(rn) == INTSXP && LENGTH(rn) == 2 && INTEGER(rn)[0] == NA_INTEGER)
-                return std::abs(INTEGER(rn)[1]);
-            return LENGTH(rn);
+	    return R_nrow( Parent::get__() );
+        }
+
+	template <typename T>
+        void push_back( const T& object){
+            Parent::push_back(object);
+            set_type_after_push();
+        }
+
+        template <typename T>
+        void push_back( const T& object, const std::string& name ){
+            Parent::push_back(object, name);
+            set_type_after_push();
+        }
+
+        template <typename T>
+        void push_front( const T& object){
+            Parent::push_front(object);
+            set_type_after_push();
+        }
+
+        template <typename T>
+        void push_front( const T& object, const std::string& name){
+            Parent::push_front(object, name);
+            set_type_after_push();
         }
 
         // Offer multiple variants to accomodate both old interface here and signatures in other classes
@@ -93,8 +98,10 @@ namespace Rcpp{
         static DataFrame_Impl create(){
             return DataFrame_Impl() ;
         }
-
-        #include <Rcpp/generated/DataFrame_generated.h>
+        template <typename... T>
+        static DataFrame_Impl create(const T&... args) {
+            return DataFrame_Impl::from_list(Parent::create(args...));
+        }
 
     private:
         void set__(SEXP x){
@@ -106,6 +113,31 @@ namespace Rcpp{
             }
         }
 
+        void set_type_after_push(){
+            R_xlen_t max_rows = 0;
+            bool invalid_column_size = false;
+            List::iterator it;
+            // Get the maximum number of rows
+            for (it = Parent::begin(); it != Parent::end(); ++it) {
+                if (Rf_xlength(*it) > max_rows) {
+                    max_rows = Rf_xlength(*it);
+                }
+            }
+            if (max_rows > 0) {
+                for (it = Parent::begin(); it != Parent::end(); ++it) {
+                    if (Rf_xlength(*it) == 0 || ( Rf_xlength(*it) > 1 && max_rows % Rf_xlength(*it) != 0 )) {
+                        // We have a column that is not an integer fraction of the largest
+                        invalid_column_size = true;
+                    }
+                }
+            }
+            if (invalid_column_size) {
+                warning("Column sizes are not equal in DataFrame::push_back, object degrading to List\n");
+            } else {
+                set__(Parent::get__());
+            }
+        }
+
         static DataFrame_Impl from_list( Parent obj ){
             bool use_default_strings_as_factors = true ;
             bool strings_as_factors = true ;
