@@ -4,7 +4,7 @@
 //
 // Copyright (C) 2008 - 2009  Dirk Eddelbuettel
 // Copyright (C) 2009 - 2020  Dirk Eddelbuettel and Romain Francois
-// Copyright (C) 2021         Dirk Eddelbuettel, Romain Francois and Iñaki Ucar
+// Copyright (C) 2021 - 2025  Dirk Eddelbuettel, Romain Francois and Iñaki Ucar
 //
 // This file is part of Rcpp.
 //
@@ -27,7 +27,9 @@
 // #define RCPP_DEBUG_LEVEL 1
 // #define RCPP_DEBUG_MODULE_LEVEL 1
 
+#include <Rcpp/r/check_r_headers.h>
 #include <Rcpp/r/headers.h>
+#include <Rcpp/r/compat.h>
 
 /**
  * \brief Rcpp API
@@ -53,6 +55,9 @@ namespace Rcpp {
 #include <iomanip>
 #include <sstream>
 #include <string>
+#if __cplusplus >= 201703L
+#include <string_view>
+#endif
 #include <list>
 #include <map>
 #include <set>
@@ -66,9 +71,8 @@ namespace Rcpp {
 #include <cfloat>
 #include <limits>
 #include <typeinfo>
+#include <utility>
 #include <Rcpp/sprintf.h>
-#include <R_ext/Callbacks.h>
-#include <R_ext/Visibility.h>
 #include <Rcpp/utils/tinyformat.h>
 
 #include <Rmath.h>
